@@ -1,9 +1,9 @@
-# -*- coding: iso8859-1 -*-
+# -*- coding: iso-8859-1 -*-
 #
-# Copyright (C) 2004-2005 Edgewall Software
+# Copyright (C) 2004-2006 Edgewall Software
 # Copyright (C) 2004-2005 Jonas Borgstrm <jonas@edgewall.com>
 # Copyright (C) 2004-2005 Daniel Lundin <daniel@edgewall.com>
-# Copyright (C) 2005 Christopher Lenz <cmlenz@gmx.de>
+# Copyright (C) 2005-2006 Christopher Lenz <cmlenz@gmx.de>
 # All rights reserved.
 #
 # This software is licensed as described in the file COPYING, which
@@ -23,6 +23,7 @@ import re
 from trac.core import *
 from trac.perm import IPermissionRequestor
 from trac.web import IRequestHandler
+from trac.util import Markup
 from trac.web.chrome import add_stylesheet, INavigationContributor
 
 
@@ -123,7 +124,7 @@ It provides an interface to the Subversion revision control systems, integrated
   <p>Trac is a product of <a href="http://www.edgewall.com/">Edgewall
   Software</a>, provider of professional Linux and software development
   services.</p>
-  <p>Copyright &copy; 2003-2005 <a href="http://www.edgewall.com/">Edgewall
+  <p>Copyright &copy; 2003-2006 <a href="http://www.edgewall.com/">Edgewall
   Software</a></p>
   <a href="http://www.edgewall.com/">
    <img style="display: block; margin: 30px" src="<?cs var:chrome.href ?>/common/edgewall.png"
@@ -139,8 +140,8 @@ It provides an interface to the Subversion revision control systems, integrated
         return 'about'
 
     def get_navigation_items(self, req):
-        yield 'metanav', 'about', '<a href="%s" accesskey="9">About Trac</a>' \
-              % self.env.href.about()
+        yield ('metanav', 'about',
+               Markup('<a href="%s">About Trac</a>', self.env.href.about()))
 
     # IPermissionRequestor methods
 
