@@ -15,6 +15,7 @@
 # Author: Jonas Borgstrm <jonas@edgewall.com>
 
 from __future__ import generators
+import re
 
 from trac import util
 from trac.core import *
@@ -95,11 +96,19 @@ class TicketSystem(Component):
             field = {'name': name, 'type': 'text', 'label': name.title()}
             fields.append(field)
 
-        custom_fields = self.get_custom_fields()
-        for field in custom_fields:
+        for field in self.get_custom_fields():
+            if field['name'] in [f['name'] for f in fields]:
+                self.log.warning('Duplicate field name "%s" (ignoring)',
+                                 field['name'])
+                continue
+            if not re.match('^[a-zA-Z][a-zA-Z0-9_]+$', field['name']):
+                self.log.warning('Invalid name for custom field: "%s" '
+                                 '(ignoring)', field['name'])
+                continue
             field['custom'] = True
+            fields.append(field)
 
-        return fields + custom_fields
+        return fields
 
     def get_custom_fields(self):
         fields = []
@@ -110,7 +119,8 @@ class TicketSystem(Component):
                 'name': name,
                 'type': self.config.get('ticket-custom', name),
                 'order': int(self.config.get('ticket-custom', name + '.order', '0')),
-                'label': self.config.get('ticket-custom', name + '.label', ''),
+                'label': self.config.get('ticket-custom', name + '.label') \
+                         or name.capitalize(),
                 'value': self.config.get('ticket-custom', name + '.value', '')
             }
             if field['type'] == 'select' or field['type'] == 'radio':
