@@ -1,7 +1,8 @@
 # -*- coding: iso-8859-1 -*-
 #
-# Copyright (C) 2003-2005 Edgewall Software
+# Copyright (C) 2003-2006 Edgewall Software
 # Copyright (C) 2003-2004 Jonas Borgstrm <jonas@edgewall.com>
+# Copyright (C) 2006 Christian Boos <cboos@neuf.fr>
 # All rights reserved.
 #
 # This software is licensed as described in the file COPYING, which
@@ -27,11 +28,6 @@ from trac.web.chrome import add_link, add_stylesheet, INavigationContributor
 from trac.wiki import wiki_to_html, IWikiSyntaxProvider
 
 
-dynvars_re = re.compile('\$([A-Z]+)')
-dynvars_disallowed_var_chars_re = re.compile('[^A-Z0-9_]')
-dynvars_disallowed_value_chars_re = re.compile(r'[^a-zA-Z0-9-_@.,\\]')
-
-
 class ColumnSorter:
 
     def __init__(self, columnIndex, asc=1):
@@ -198,7 +194,7 @@ class ReportModule(Component):
         req.hdf['report'] = {
             'id': id,
             'mode': 'delete',
-            'title': util.row[0],
+            'title': row[0],
             'href': self.env.href.report(id)
         }
 
@@ -256,7 +252,8 @@ class ReportModule(Component):
 
         title, description, sql = self.get_info(db, id, args)
 
-        if req.args.get('format') == 'sql':
+        format = req.args.get('format')
+        if format == 'sql':
             self._render_sql(req, id, title, description, sql)
             return
 
@@ -339,19 +336,21 @@ class ReportModule(Component):
                 elif column[0] == '_':
                     value['hidehtml'] = 1
                     column = column[1:]
-                if column in ['id', 'ticket', '#', 'summary']:
+                if column in ('ticket', 'id', '_id', '#', 'summary'):
                     id_cols = [idx for idx, col in util.enum(cols)
-                               if col[0] in ('ticket', 'id')]
+                               if col[0] in ('ticket', 'id', '_id')]
                     if id_cols:
                         id_val = row[id_cols[0]]
                         value['ticket_href'] = self.env.href.ticket(id_val)
                 elif column == 'description':
-                    value['parsed'] = wiki_to_html(cell, self.env, req, db)
+                    descr = wiki_to_html(cell, self.env, req, db,
+                                         absurls=(format == 'rss'))
+                    value['parsed'] = format == 'rss' and str(descr) or descr
                 elif column == 'reporter' and cell.find('@') != -1:
                     value['rss'] = cell
                 elif column == 'report':
                     value['report_href'] = self.env.href.report(cell)
-                elif column in ['time', 'date','changetime', 'created', 'modified']:
+                elif column in ('time', 'date','changetime', 'created', 'modified'):
                     value['date'] = util.format_date(cell)
                     value['time'] = util.format_time(cell)
                     value['datetime'] = util.format_datetime(cell)
@@ -365,9 +364,7 @@ class ReportModule(Component):
             row_idx += 1
         req.hdf['report.numrows'] = row_idx
 
-        format = req.args.get('format')
         if format == 'rss':
-            self._render_rss(req)
             return 'report_rss.cs', 'application/rss+xml'
         elif format == 'csv':
             self._render_csv(req, cols, rows)
@@ -398,14 +395,16 @@ class ReportModule(Component):
                      'text/plain')
 
     def execute_report(self, req, db, id, sql, args):
-        sql = self.sql_sub_vars(req, sql, args)
+        sql, args = self.sql_sub_vars(req, sql, args)
         if not sql:
             raise util.TracError('Report %s has no SQL query.' % id)
         if sql.find('__group__') == -1:
             req.hdf['report.sorting.enabled'] = 1
 
+        self.log.debug('Executing report with SQL "%s" (%s)', sql, args)
+
         cursor = db.cursor()
-        cursor.execute(sql)
+        cursor.execute(sql, args)
 
         # FIXME: fetchall should probably not be used.
         info = cursor.fetchall() or []
@@ -441,16 +440,7 @@ class ReportModule(Component):
         for arg in req.args.keys():
             if not arg == arg.upper():
                 continue
-            m = re.search(dynvars_disallowed_var_chars_re, arg)
-            if m:
-                raise ValueError("The character '%s' is not allowed "
-                                 " in variable names." % m.group())
-            val = req.args.get(arg)
-            m = re.search(dynvars_disallowed_value_chars_re, val)
-            if m:
-                raise ValueError("The character '%s' is not allowed "
-                                 " in variable data." % m.group())
-            report_args[arg] = val
+            report_args[arg] = req.args.get(arg)
 
         # Set some default dynamic variables
         if not report_args.has_key('USER'):
@@ -459,16 +449,18 @@ class ReportModule(Component):
         return report_args
 
     def sql_sub_vars(self, req, sql, args):
+        values = []
         def repl(match):
-            aname = match.group()[1:]
+            aname = match.group(1)
             try:
                 arg = args[aname]
             except KeyError:
                 raise util.TracError("Dynamic variable '$%s' not defined." % aname)
             req.hdf['report.var.' + aname] = arg
-            return arg
+            values.append(arg)
+            return '%s'
 
-        return dynvars_re.sub(repl, sql)
+        return re.sub("'?\$([A-Z]+)'?", repl, sql), values
 
     def _render_csv(self, req, cols, rows, sep=','):
         req.send_response(200)
@@ -482,18 +474,6 @@ class ReportModule(Component):
                                        .replace('\r',' ')
             req.write(sep.join(map(sanitize, row)) + '\r\n')
 
-    def _render_rss(self, req):
-        # Escape HTML in the ticket summaries
-        item = req.hdf.getObj('report.items')
-        if item:
-            item = item.child()
-            while item:
-                for col in ('summary', 'description.parsed'):
-                    nodename = 'report.items.%s.%s' % (item.name(), col)
-                    value = req.hdf.get(nodename, '')
-                    req.hdf[nodename] = value
-                item = item.next()
-
     def _render_sql(self, req, id, title, description, sql):
         req.perm.assert_permission('REPORT_SQL_VIEW')
         req.send_response(200)
