@@ -1,4 +1,4 @@
-# -*- coding: iso8859-1 -*-
+# -*- coding: iso-8859-1 -*-
 #
 # Copyright (C) 2005 Edgewall Software
 # Copyright (C) 2005 Christopher Lenz <cmlenz@gmx.de>
@@ -92,10 +92,10 @@ class SubversionRepositoryTestCase(unittest.TestCase):
         self.assertEqual('trunk', self.repos.normalize_path('/trunk/'))
 
     def test_repos_normalize_rev(self):
-        self.assertEqual(12, self.repos.normalize_rev('latest'))
-        self.assertEqual(12, self.repos.normalize_rev('head'))
-        self.assertEqual(12, self.repos.normalize_rev(''))
-        self.assertEqual(12, self.repos.normalize_rev(None))
+        self.assertEqual(16, self.repos.normalize_rev('latest'))
+        self.assertEqual(16, self.repos.normalize_rev('head'))
+        self.assertEqual(16, self.repos.normalize_rev(''))
+        self.assertEqual(16, self.repos.normalize_rev(None))
         self.assertEqual(11, self.repos.normalize_rev('11'))
         self.assertEqual(11, self.repos.normalize_rev(11))
 
@@ -103,11 +103,11 @@ class SubversionRepositoryTestCase(unittest.TestCase):
         self.assertEqual(0, self.repos.oldest_rev)
         self.assertEqual(None, self.repos.previous_rev(0))
         self.assertEqual(0, self.repos.previous_rev(1))
-        self.assertEqual(12, self.repos.youngest_rev)
+        self.assertEqual(16, self.repos.youngest_rev)
         self.assertEqual(6, self.repos.next_rev(5))
         self.assertEqual(7, self.repos.next_rev(6))
         # ...
-        self.assertEqual(None, self.repos.next_rev(12))
+        self.assertEqual(None, self.repos.next_rev(16))
 
     def test_has_node(self):
         self.assertEqual(False, self.repos.has_node('/trunk/dir1', 3))
@@ -118,8 +118,8 @@ class SubversionRepositoryTestCase(unittest.TestCase):
         self.assertEqual('trunk', node.name)
         self.assertEqual('/trunk', node.path)
         self.assertEqual(Node.DIRECTORY, node.kind)
-        self.assertEqual(6, node.rev)
-        self.assertEqual(1112381806, node.last_modified)
+        self.assertEqual(14, node.rev)
+        self.assertEqual(1133340423L, node.last_modified)
         node = self.repos.get_node('/trunk/README.txt')
         self.assertEqual('README.txt', node.name)
         self.assertEqual('/trunk/README.txt', node.path)
@@ -144,8 +144,8 @@ class SubversionRepositoryTestCase(unittest.TestCase):
     def test_get_dir_entries(self):
         node = self.repos.get_node('/trunk')
         entries = node.get_entries()
-        self.assertEqual('README2.txt', entries.next().name)
         self.assertEqual('dir1', entries.next().name)
+        self.assertEqual('README3.txt', entries.next().name)
         self.assertEqual('README.txt', entries.next().name)
         self.assertRaises(StopIteration, entries.next)
 
@@ -169,7 +169,7 @@ class SubversionRepositoryTestCase(unittest.TestCase):
     def test_get_dir_properties(self):
         f = self.repos.get_node('/trunk')
         props = f.get_properties()
-        self.assertEqual(0, len(props))
+        self.assertEqual(1, len(props))
 
     def test_get_file_properties(self):
         f = self.repos.get_node('/trunk/README.txt')
@@ -180,8 +180,9 @@ class SubversionRepositoryTestCase(unittest.TestCase):
     # Revision Log / node history 
 
     def test_get_node_history(self):
-        node = self.repos.get_node('/trunk/README2.txt')
+        node = self.repos.get_node('/trunk/README3.txt')
         history = node.get_history()
+        self.assertEqual(('trunk/README3.txt', 14, 'copy'), history.next())
         self.assertEqual(('trunk/README2.txt', 6, 'copy'), history.next())
         self.assertEqual(('trunk/README.txt', 3, 'edit'), history.next())
         self.assertEqual(('trunk/README.txt', 2, 'add'), history.next())
@@ -199,6 +200,7 @@ class SubversionRepositoryTestCase(unittest.TestCase):
 
     def test_get_path_history(self):
         history = self.repos.get_path_history('/trunk/README2.txt', None)
+        self.assertEqual(('trunk/README2.txt', 14, 'delete'), history.next())
         self.assertEqual(('trunk/README2.txt', 6, 'copy'), history.next())
         self.assertEqual(('trunk/README.txt', 3, 'unknown'), history.next())
         self.assertRaises(StopIteration, history.next)
@@ -281,6 +283,48 @@ class SubversionRepositoryTestCase(unittest.TestCase):
                           'trunk/README.txt', 3), changes.next())
         self.assertRaises(StopIteration, changes.next)
 
+    def test_changeset_root_propset(self):
+        chgset = self.repos.get_changeset(13)
+        self.assertEqual(13, chgset.rev)
+        self.assertEqual('Setting property on the repository_dir root',
+                         chgset.message)
+        changes = chgset.get_changes()
+        self.assertEqual(('', Node.DIRECTORY, Changeset.EDIT, '/', 12),
+                         changes.next())
+        self.assertEqual(('trunk', Node.DIRECTORY, Changeset.EDIT, 'trunk', 6),
+                         changes.next())
+        self.assertRaises(StopIteration, changes.next)
+
+    def test_changeset_base_path_rev(self):
+        chgset = self.repos.get_changeset(9)
+        self.assertEqual(9, chgset.rev)
+        changes = chgset.get_changes()
+        self.assertEqual(('branches/v1x/README.txt', Node.FILE,
+                          Changeset.EDIT, 'trunk/README.txt', 3),
+                         changes.next())
+        self.assertRaises(StopIteration, changes.next)
+
+    def test_changeset_rename_and_edit(self):
+        chgset = self.repos.get_changeset(14)
+        self.assertEqual(14, chgset.rev)
+        changes = chgset.get_changes()
+        self.assertEqual(('trunk/README3.txt', Node.FILE,
+                          Changeset.MOVE, 'trunk/README2.txt', 13),
+                         changes.next())
+        self.assertRaises(StopIteration, changes.next)
+
+    def test_changeset_edit_after_wc2wc_copy__original_deleted(self):
+        chgset = self.repos.get_changeset(16)
+        self.assertEqual(16, chgset.rev)
+        changes = chgset.get_changes()
+        self.assertEqual(('branches/v2', Node.DIRECTORY, Changeset.COPY,
+                          'tags/v1.1', 14),
+                         changes.next())
+        self.assertEqual(('branches/v2/README2.txt', Node.FILE,
+                          Changeset.EDIT, 'trunk/README2.txt', 6),
+                         changes.next())
+        self.assertRaises(StopIteration, changes.next)
+
 
 class ScopedSubversionRepositoryTestCase(unittest.TestCase):
 
@@ -301,10 +345,10 @@ class ScopedSubversionRepositoryTestCase(unittest.TestCase):
         self.assertEqual('dir1', self.repos.normalize_path('/dir1/'))
 
     def test_repos_normalize_rev(self):
-        self.assertEqual(6, self.repos.normalize_rev('latest'))
-        self.assertEqual(6, self.repos.normalize_rev('head'))
-        self.assertEqual(6, self.repos.normalize_rev(''))
-        self.assertEqual(6, self.repos.normalize_rev(None))
+        self.assertEqual(14, self.repos.normalize_rev('latest'))
+        self.assertEqual(14, self.repos.normalize_rev('head'))
+        self.assertEqual(14, self.repos.normalize_rev(''))
+        self.assertEqual(14, self.repos.normalize_rev(None))
         self.assertEqual(5, self.repos.normalize_rev('5'))
         self.assertEqual(5, self.repos.normalize_rev(5))
 
@@ -312,11 +356,11 @@ class ScopedSubversionRepositoryTestCase(unittest.TestCase):
         self.assertEqual(1, self.repos.oldest_rev)
         self.assertEqual(None, self.repos.previous_rev(0))
         self.assertEqual(1, self.repos.previous_rev(2))
-        self.assertEqual(6, self.repos.youngest_rev)
+        self.assertEqual(14, self.repos.youngest_rev)
         self.assertEqual(2, self.repos.next_rev(1))
         self.assertEqual(3, self.repos.next_rev(2))
         # ...
-        self.assertEqual(None, self.repos.next_rev(6))
+        self.assertEqual(None, self.repos.next_rev(14))
 
     def test_has_node(self):
         self.assertEqual(False, self.repos.has_node('/dir1', 3))
@@ -353,8 +397,8 @@ class ScopedSubversionRepositoryTestCase(unittest.TestCase):
     def test_get_dir_entries(self):
         node = self.repos.get_node('/')
         entries = node.get_entries()
-        self.assertEqual('README2.txt', entries.next().name)
         self.assertEqual('dir1', entries.next().name)
+        self.assertEqual('README3.txt', entries.next().name)
         self.assertEqual('README.txt', entries.next().name)
         self.assertRaises(StopIteration, entries.next)
 
@@ -389,8 +433,9 @@ class ScopedSubversionRepositoryTestCase(unittest.TestCase):
     # Revision Log / node history 
 
     def test_get_node_history(self):
-        node = self.repos.get_node('/README2.txt')
+        node = self.repos.get_node('/README3.txt')
         history = node.get_history()
+        self.assertEqual(('README3.txt', 14, 'copy'), history.next())
         self.assertEqual(('README2.txt', 6, 'copy'), history.next())
         self.assertEqual(('README.txt', 3, 'edit'), history.next())
         self.assertEqual(('README.txt', 2, 'add'), history.next())
@@ -412,9 +457,9 @@ class ScopedSubversionRepositoryTestCase(unittest.TestCase):
         self.assertRaises(StopIteration, history.next)
 
     def test_get_path_history_copied_file(self):
-        history = self.repos.get_path_history('README2.txt', None)
-        self.assertEqual(('README2.txt', 6, 'copy'), history.next())
-        self.assertEqual(('README.txt', 3, 'unknown'), history.next())
+        history = self.repos.get_path_history('README3.txt', None)
+        self.assertEqual(('README3.txt', 14, 'copy'), history.next())
+        self.assertEqual(('README2.txt', 6, 'unknown'), history.next())
         self.assertRaises(StopIteration, history.next)
         
     def test_get_path_history_copied_dir(self):
@@ -485,6 +530,15 @@ class ScopedSubversionRepositoryTestCase(unittest.TestCase):
                           'README.txt', 3), changes.next())
         self.assertRaises(StopIteration, changes.next)
 
+    def test_changeset_root_propset(self):
+        chgset = self.repos.get_changeset(13)
+        self.assertEqual(13, chgset.rev)
+        self.assertEqual('Setting property on the repository_dir root',
+                         chgset.message)
+        changes = chgset.get_changes()
+        self.assertEqual(('', Node.DIRECTORY, Changeset.EDIT, '/', 6),
+                         changes.next())
+        self.assertRaises(StopIteration, changes.next)
 
 def suite():
     suite = unittest.TestSuite()
